/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Yahoo! Mail Notifier code.
 *
 * The Initial Developer of the Original Code is
 * Michael Kraft.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var Cc = Components.classes;
var Ci = Components.interfaces;

var ym_options = {
	sound : null,

	//
	// User clicked Okay so verify and save the user preferences
	//
	doOK : function() {
		var intervalMinutes = document.getElementById("ym-notifier-interval").value;
		var strings = document.getElementById("ym-notifierStrings");

		// Check for valid interval (integers only)
		var objRegExp  = /(^-?\d\d*$)/;
		if (intervalMinutes == null || !objRegExp.test(intervalMinutes) || 
		    (intervalMinutes <= 0) || (intervalMinutes > 60)) {
			alert (strings.getString("badinterval"));
			document.getElementById("ym-notifier-interval").value = ym_prefs.getPref(ym_prefs.PREF_INTERVAL);
			return false;
		}

		ym_prefs.setPref(ym_prefs.PREF_INTERVAL, parseInt(document.getElementById("ym-notifier-interval").value));
		ym_prefs.setPref(ym_prefs.PREF_AUTO_CHECK, document.getElementById("ym-notifier-auto-check").checked);
	
		// Convert radio and menu lists into one preference
		var clickPref = document.getElementById("ym-notifier-click").selectedIndex;
		if (document.getElementById("ym-notifier-radio-click").selectedIndex == 0)
			ym_prefs.setPref(ym_prefs.PREF_CLICK, clickPref + ym_prefs.CONST_CHECKMAIL);
		else ym_prefs.setPref(ym_prefs.PREF_CLICK, clickPref);
		
		clickPref = document.getElementById("ym-notifier-dblclick").selectedIndex;
		if (document.getElementById("ym-notifier-radio-dblclick").selectedIndex == 0)
			ym_prefs.setPref(ym_prefs.PREF_DOUBLECLICK, clickPref + ym_prefs.CONST_CHECKMAIL);
		else ym_prefs.setPref(ym_prefs.PREF_DOUBLECLICK, clickPref);

		clickPref = document.getElementById("ym-notifier-midclick").selectedIndex;
		if (document.getElementById("ym-notifier-radio-midclick").selectedIndex == 0)
			ym_prefs.setPref(ym_prefs.PREF_MIDDLECLICK, clickPref + ym_prefs.CONST_CHECKMAIL);
		else ym_prefs.setPref(ym_prefs.PREF_MIDDLECLICK, clickPref);

		ym_prefs.setPref(ym_prefs.PREF_STATUSBAR, document.getElementById("ym-notifier-statusbar").selectedIndex);
		ym_prefs.setPref(ym_prefs.PREF_SHOW_POPUP, document.getElementById("ym-notifier-show-popup").selectedIndex);
		ym_prefs.setPref(ym_prefs.PREF_SHOW_ALERTS, document.getElementById("ym-notifier-show-alerts").selectedIndex);
		ym_prefs.setPref(ym_prefs.PREF_SOUND, document.getElementById("ym-notifier-sound").selectedIndex);
		ym_prefs.setPref(ym_prefs.PREF_SOUNDFILE, encodeURIComponent(document.getElementById("ym-notifier-soundfile").value));
		 
		return true;
	},

	//
	// Retrieve the user preferences
	//
	doLoad : function() {
		document.getElementById("ym-notifier-interval").value = ym_prefs.getPref(ym_prefs.PREF_INTERVAL);
		document.getElementById("ym-notifier-auto-check").checked = ym_prefs.getPref(ym_prefs.PREF_AUTO_CHECK);

		// need to convert click preference into menulist and radio button
		var clickPref = ym_prefs.getPref(ym_prefs.PREF_CLICK);
		if (clickPref >= ym_prefs.CONST_CHECKMAIL) {
			document.getElementById("ym-notifier-click").selectedIndex = clickPref - ym_prefs.CONST_CHECKMAIL;
			document.getElementById("ym-notifier-radio-click").selectedIndex = 0;
		} 
		else {
			document.getElementById("ym-notifier-click").selectedIndex = clickPref;
			document.getElementById("ym-notifier-radio-click").selectedIndex = 1;
		}
	
		clickPref = ym_prefs.getPref(ym_prefs.PREF_DOUBLECLICK);
		if (clickPref >= ym_prefs.CONST_CHECKMAIL) {
			document.getElementById("ym-notifier-dblclick").selectedIndex = clickPref - ym_prefs.CONST_CHECKMAIL;
			document.getElementById("ym-notifier-radio-dblclick").selectedIndex = 0;
		} 
		else {
			document.getElementById("ym-notifier-dblclick").selectedIndex = clickPref;
			document.getElementById("ym-notifier-radio-dblclick").selectedIndex = 1;
		}

		clickPref = ym_prefs.getPref(ym_prefs.PREF_MIDDLECLICK);
		if (clickPref >= ym_prefs.CONST_CHECKMAIL) {
			document.getElementById("ym-notifier-midclick").selectedIndex = clickPref - ym_prefs.CONST_CHECKMAIL;
			document.getElementById("ym-notifier-radio-midclick").selectedIndex = 0;
		} 
		else {
			document.getElementById("ym-notifier-midclick").selectedIndex = clickPref;
			document.getElementById("ym-notifier-radio-midclick").selectedIndex = 1;
		}
		this.updateRadio();

		document.getElementById("ym-notifier-statusbar").selectedIndex = ym_prefs.getPref(ym_prefs.PREF_STATUSBAR);
		document.getElementById("ym-notifier-show-popup").selectedIndex = ym_prefs.getPref(ym_prefs.PREF_SHOW_POPUP);

		// hide option to hide status bar on Mozilla and SeaMonkey since they have no way of unhiding it
		if (gYm_notifier.isMozillaOrSeaMonkey1())
			 document.getElementById("ym-notifier-statusbar-row").setAttribute("hidden", "true");
	
		// alerts aren't supported on all platforms so hide it if its not supported
		var alert_okay = false;
		try {
			var grn = Cc["@growl.info/notifications;1"].getService(Ci.grINotifications);
			document.getElementById("ym-notifier-show-alerts").selectedIndex = ym_prefs.getPref(ym_prefs.PREF_SHOW_ALERTS);
			alert_okay = true;
		}
		catch(ex) {}
		if (!alert_okay) {
			try {
				var alert = Cc["@mozilla.org/alerts-service;1"].getService(Ci.nsIAlertsService);
				document.getElementById("ym-notifier-show-alerts").selectedIndex = ym_prefs.getPref(ym_prefs.PREF_SHOW_ALERTS);
			alert_okay = true;
			}
			catch(ex) {}
		}
		if (!alert_okay) {
			document.getElementById("ym-notifier-show-alerts").selectedIndex = ym_prefs.CONST_NEVER;
			document.getElementById("ym-notifier-alerts-row").setAttribute("hidden", "true");
		}

		// sounds aren't supported on all platforms so hide it if its not supported
		try
		{
			this.sound = Cc["@mozilla.org/sound;1"].createInstance(Ci.nsISound);

			var sound_choice =ym_prefs.getPref(ym_prefs.PREF_SOUND);
			document.getElementById("ym-notifier-sound").selectedIndex = sound_choice;
			document.getElementById("ym-notifier-soundfile").value = decodeURIComponent(ym_prefs.getPref(ym_prefs.PREF_SOUNDFILE));
				 
			this.updateSound(sound_choice);
		}
		catch(e)
		{
			document.getElementById("ym-notifier-sound").selectedIndex = ym_prefs.CONST_NEVER;
			document.getElementById("ym-notifier-soundfile").value = "";
			document.getElementById("ym-notifier-sound-row").setAttribute("hidden", "true");
			document.getElementById("ym-notifier-sound2-row").setAttribute("hidden", "true");
			document.getElementById("ym-notifier-sound3-row").setAttribute("hidden", "true");
		} 		 

		return true;
	},
	 
	//
	// Plays the specfied sound when user clicks the preview button
	//
	previewSound : function() {
		var soundUrl = document.getElementById("ym-notifier-soundfile").value;
		var failed = false;
		var FileFactory = null;
		var soundFile = null;
		var aURI = false;

		// play default system mail sound if nothing specified
		if (soundUrl=="") {
			this.sound.playSystemSound("_moz_mailbeep"); 
			failed = true;
		}
		// if a URL use that
		else if (soundUrl.indexOf("://") != -1) {
			soundFile = soundUrl;
			aURI = true;
		}
		// must be a filename (local or absolute)
		else {
			failed = true;	// default to fail
			try {
				FileFactory = new Components.Constructor('@mozilla.org/file/local;1', 'nsILocalFile', 'initWithPath');
				soundFile = new FileFactory(soundUrl);
				failed = false;
			} 
			catch (e) {}

			// if fail try to use a relative path in the chrome directory
			if (failed) {
				try {
					// get user chrome directory ( see http://kb.mozillazine.org/File_IO#Getting_special_files )
					var file = Cc["@mozilla.org/file/directory_service;1"].getService(Ci.nsIProperties).get("UChrm", Ci.nsIFile);
					file.append(soundUrl);
					FileFactory = new Components.Constructor('@mozilla.org/file/local;1', 'nsILocalFile', 'initWithFile');
					soundFile = new FileFactory(file);
					failed = false;
				} 
				catch (e) {}
			}
		}
		if (!failed) {
			try {
				var soundURI = null;
				var nsIIOService = Cc['@mozilla.org/network/io-service;1'].getService(Ci.nsIIOService);
				if (aURI) soundURI = nsIIOService.newURI(soundFile,null,null);
				else soundURI =  nsIIOService.newFileURI(soundFile);
				this.sound.play(soundURI);
			} 
			catch (e) {}
		}
	},

	//
 	// Allows user to browse for and select a sound file.  Only .wav files are supported on Windows.
	//
	selectSound : function() {
		var nsIFilePicker = Ci.nsIFilePicker;
		var filepicker = Cc["@mozilla.org/filepicker;1"].createInstance(nsIFilePicker);

		filepicker.init(window, document.getElementById("ym-notifierStrings").getString("choosesound"), nsIFilePicker.modeOpen);
		filepicker.appendFilters(nsIFilePicker.filterAll);
		var ret = filepicker.show();
		if (ret == nsIFilePicker.returnOK)
			document.getElementById("ym-notifier-soundfile").value = filepicker.file.path;
	}, 	 
		 
	//
	// If sounds are disabled, hide choices
	//
	updateSound : function(aInt) {
		if (aInt != 0) {
			document.getElementById("ym-notifier-soundfile-default").disabled = false;
			document.getElementById("ym-notifier-soundfile-select").disabled = false;
			document.getElementById("ym-notifier-soundfile-preview").disabled = false;	 
			document.getElementById("ym-notifier-soundfile").disabled = false;
		}
		else {
			document.getElementById("ym-notifier-soundfile-default").disabled = true;
			document.getElementById("ym-notifier-soundfile-select").disabled = true;
			document.getElementById("ym-notifier-soundfile-preview").disabled = true; 	 
			document.getElementById("ym-notifier-soundfile").disabled = true;
		}  
	},

	//
	// On radio button press check to see if menulist needs to be disabled.
	//
	updateRadio : function() {
		document.getElementById("ym-notifier-click").setAttribute("hidden",  
			(document.getElementById("ym-notifier-radio-click").selectedIndex == 0));

		document.getElementById("ym-notifier-dblclick").setAttribute("hidden",	
			(document.getElementById("ym-notifier-radio-dblclick").selectedIndex == 0));

		document.getElementById("ym-notifier-midclick").setAttribute("hidden",	
			(document.getElementById("ym-notifier-radio-midclick").selectedIndex == 0));
	}
}
